@@ -27,18 +27,19 @@
 
 namespace Wacom
 {
-    class TabletBackendPrivate
-    {
-        public:
-            TabletBackend::DeviceMap deviceAdaptors;
-            PropertyAdaptor*         statusLEDAdaptor;
-            TabletInformation        tabletInformation;
-    };
+class TabletBackendPrivate
+{
+public:
+    TabletBackend::DeviceMap deviceAdaptors;
+    PropertyAdaptor *statusLEDAdaptor;
+    TabletInformation tabletInformation;
+};
 }
 
 using namespace Wacom;
 
-TabletBackend::TabletBackend(const Wacom::TabletInformation& tabletInformation) : d_ptr(new TabletBackendPrivate)
+TabletBackend::TabletBackend(const Wacom::TabletInformation &tabletInformation)
+    : d_ptr(new TabletBackendPrivate)
 {
     Q_D(TabletBackend);
     d->tabletInformation = tabletInformation;
@@ -51,7 +52,7 @@ TabletBackend::~TabletBackend()
     // delete all property adaptors
     DeviceMap::iterator deviceIter;
 
-    for (deviceIter = d_ptr->deviceAdaptors.begin() ; deviceIter != d_ptr->deviceAdaptors.end() ; ++deviceIter) {
+    for (deviceIter = d_ptr->deviceAdaptors.begin(); deviceIter != d_ptr->deviceAdaptors.end(); ++deviceIter) {
         AdaptorList::iterator adaptorIter = deviceIter.value().begin();
 
         while (adaptorIter != deviceIter.value().end()) {
@@ -66,26 +67,20 @@ TabletBackend::~TabletBackend()
     delete d_ptr;
 }
 
-
-
-void TabletBackend::addAdaptor(const DeviceType& deviceType, PropertyAdaptor* adaptor)
+void TabletBackend::addAdaptor(const DeviceType &deviceType, PropertyAdaptor *adaptor)
 {
     Q_D(TabletBackend);
 
     d->deviceAdaptors[deviceType].append(adaptor);
 }
 
-
-
-const TabletInformation& TabletBackend::getInformation() const
+const TabletInformation &TabletBackend::getInformation() const
 {
     Q_D(const TabletBackend);
     return d->tabletInformation;
 }
 
-
-
-const QString TabletBackend::getProperty(const DeviceType& type, const Property& property) const
+const QString TabletBackend::getProperty(const DeviceType &type, const Property &property) const
 {
     Q_D(const TabletBackend);
 
@@ -95,7 +90,7 @@ const QString TabletBackend::getProperty(const DeviceType& type, const Property&
         return QString();
     }
 
-    foreach(const PropertyAdaptor* adaptor, adaptors.value()) {
+    foreach (const PropertyAdaptor *adaptor, adaptors.value()) {
         if (adaptor->supportsProperty(property)) {
             return adaptor->getProperty(property);
         }
@@ -104,20 +99,22 @@ const QString TabletBackend::getProperty(const DeviceType& type, const Property&
     return QString();
 }
 
-
-
-void TabletBackend::setProfile(const TabletProfile& profile)
+void TabletBackend::setProfile(const TabletProfile &profile)
 {
     Q_D(TabletBackend);
 
-    foreach(const DeviceType& deviceType, DeviceType::list()) {
+    foreach (const DeviceType &deviceType, DeviceType::list()) {
         if (d->tabletInformation.hasDevice(deviceType)) {
             if (profile.hasDevice(deviceType)) {
-                qCDebug(KDED) << QString::fromLatin1("Setting profile '%1' on tablet '%2', device '%3'").arg(profile.getName()).arg(d->tabletInformation.get(TabletInfo::TabletName)).arg(deviceType.key());
+                qCDebug(KDED) << QString::fromLatin1("Setting profile '%1' on tablet '%2', device '%3'")
+                                     .arg(profile.getName())
+                                     .arg(d->tabletInformation.get(TabletInfo::TabletName))
+                                     .arg(deviceType.key());
                 DeviceProfile deviceProfile = profile.getDevice(deviceType);
                 setProfile(deviceType, deviceProfile);
             } else {
-                qCDebug(KDED) << QString::fromLatin1("Skipping '%1' settings as the current profile does not contain any settings for this device...").arg(deviceType.key());
+                qCDebug(KDED) << QString::fromLatin1("Skipping '%1' settings as the current profile does not contain any settings for this device...")
+                                     .arg(deviceType.key());
             }
         } else {
             qCDebug(KDED) << QString::fromLatin1("Skipping '%1' settings as the device does not support it...").arg(deviceType.key());
@@ -125,9 +122,7 @@ void TabletBackend::setProfile(const TabletProfile& profile)
     }
 }
 
-
-
-void TabletBackend::setProfile(const DeviceType& deviceType, const DeviceProfile& profile)
+void TabletBackend::setProfile(const DeviceType &deviceType, const DeviceProfile &profile)
 {
     Q_D(TabletBackend);
 
@@ -140,12 +135,10 @@ void TabletBackend::setProfile(const DeviceType& deviceType, const DeviceProfile
     QString value;
 
     // set properties on all adaptors
-    foreach(PropertyAdaptor* adaptor, adaptors.value()) {
-
+    foreach (PropertyAdaptor *adaptor, adaptors.value()) {
         // ask adaptor which properties it supports
         // this will also ensure that the properties are set in the correct order
-        foreach(const Property& property, adaptor->getProperties()) {
-
+        foreach (const Property &property, adaptor->getProperties()) {
             // set property value if it is supported by the profile and not empty
             if (profile.supportsProperty(property)) {
                 value = profile.getProperty(property);
@@ -174,18 +167,19 @@ void TabletBackend::setStatusLEDBrightness(int brightness)
     }
 }
 
-bool TabletBackend::setProperty(const DeviceType& type, const Property& property, const QString& value)
+bool TabletBackend::setProperty(const DeviceType &type, const Property &property, const QString &value)
 {
     Q_D(TabletBackend);
 
     DeviceMap::iterator adaptors = d->deviceAdaptors.find(type);
     if (adaptors == d->deviceAdaptors.end()) {
-        qCWarning(KDED) << QString::fromLatin1("Could not set property '%1' to '%2' on unsupported device type '%3'!").arg(property.key()).arg(value).arg(type.key());
+        qCWarning(KDED)
+            << QString::fromLatin1("Could not set property '%1' to '%2' on unsupported device type '%3'!").arg(property.key()).arg(value).arg(type.key());
         return false;
     }
 
     bool returnValue = false;
-    foreach (PropertyAdaptor* adaptor, adaptors.value()) {
+    foreach (PropertyAdaptor *adaptor, adaptors.value()) {
         if (adaptor->supportsProperty(property)) {
             if (adaptor->setProperty(property, value)) {
                 returnValue = true;
